@@ -1,6 +1,5 @@
 import json
 import os
-from copy import deepcopy
 from typing import List, Optional, Union
 
 from ..common import S3Artifact
@@ -8,7 +7,7 @@ from ..config import config
 from ..executor import Executor, render_script_with_tmp_root, run_script
 from ..io import InputArtifact, InputParameter
 from ..op_template import ScriptOPTemplate
-from ..utils import randstr, upload_s3
+from ..utils import upload_s3
 from . import bohrium
 
 try:
@@ -201,8 +200,7 @@ class DispatcherExecutor(Executor):
         if not isinstance(template, ScriptOPTemplate):
             return template
 
-        new_template = deepcopy(template)
-        new_template.name += "-" + randstr()
+        new_template = template.copy()
         new_template.image = self.image
         new_template.image_pull_policy = self.image_pull_policy
         new_template.command = self.command
